@@ -8,7 +8,7 @@
 */
 
 #pragma once
-
+#include "kcmutils_version.h"
 #include "ui_todosummaryconfig_base.h"
 #include <KCModule>
 
@@ -17,7 +17,11 @@ class KCMTodoSummary : public KCModule, public Ui::TodoSummaryConfig_Base
     Q_OBJECT
 
 public:
-    explicit KCMTodoSummary(QWidget *parent = nullptr, const QVariantList &args = {});
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
+    explicit KCMTodoSummary(QWidget *parent = nullptr, const QVariantList &args = QVariantList());
+#else
+    explicit KCMTodoSummary(QObject *parent, const KPluginMetaData &data, const QVariantList &args = QVariantList());
+#endif
     ~KCMTodoSummary() override;
 
     void load() override;
